
package engine;

import common.CommonVariables;

/**
 * This class computes the status of the game
 * after each move by a player, the method of this
 * class is called. 
 * the server machine is always using X
 * the client machine is always using O
 * 
 * @author sumanta
 */
public class GameEngine {
    private char[][] board = new char[3][3];
    private boolean isWinner = false;
    
    public GameEngine()
    {
        //init the board
        //q means nothing or empty cell
        //x is cross
        //o is zero
        for (int i = 0; i < board.length; i++) {
            for (int j = 0; j < board[i].length; j++) {
                board[i][j] = 'q';
            }
        }
    }
    
    /*
     * This method computes the result of the game at any moment 
     * depending upon the board array
     * 
     * @param none
     * @return boolean
     * 
     */
    public boolean computeResult()
    {
       int count=0;
       char myChar = CommonVariables.myName.equals("server") ? 'X':'O';
       
       //check horizontally for any winner
        for (int i = 0; i < board.length; i++) {
            for (int j = 0; j < board[i].length; j++) {
                if(board[i][j] == myChar)
                    count++;
            }
            //one row checking complete, check whether you won or not
            if(count == 3)
                return true;
            else count = 0;
        }

       //check vertically for any winner
        for (int i = 0; i < board.length; i++) {
            for (int j = 0; j < board[i].length; j++) {
                if(board[j][i] == myChar)
                    count++;
            }
            //one row checking complete, check whether you won or not
            if(count == 3)
                return true;
            else count = 0;
        }
       
       //check diagonally
       if(board[0][0]==myChar && board[1][1]==myChar && board[2][2]==myChar )
           return true;
       //check diagonally
       if(board[0][2]==myChar && board[1][1]==myChar && board[2][0]==myChar )
           return true;
       
       return false;
    }
    
    /*
     * this method sets the cell denoted by (x, y)
     * according to hte value of myName.
     * 
     * @return boolean indicating whether move is valid or not
     */
//    public boolean setMove(int x, int y)
//    {
//        char myChar = CommonVariables.myName.equals("server") ? 'X':'O';
//        if(board[x][y] == 'q')
//        {
//            board[x][y] = myChar;
//            return true;
//        }
//        return false;
//    }
    
    /*
     * Overloaded method
     * works with the keypad number of the keyboard
     * derives the coordinate according to the number
     * pressed by the user
     * 
     * @param int keypad number pressed
     * @param boolean whether mine or opposition's move
     * @return valid move or not
     */
    public boolean setMove(int num, boolean isMyMove)
    {
        char charToSet;
        if(isMyMove)
            charToSet = CommonVariables.myChar;
        else
            charToSet = (CommonVariables.myChar=='X') ? 'O':'X';
        
        num--; //making it an index
        
        //hehe, simple logic, think how the numerical number is converted to row, column index
        if(board[num/3][num%3] == 'q')
        {
            System.out.println("I am "+CommonVariables.myName+ " and setting ["+num/3+num%3+" to "+charToSet);
            board[num/3][num%3] = charToSet;
            return true;
        }
        return false;
    }

    public char[][] getBoard() {
        return board;
    }
    
}
